import { createRouter, createWebHistory, RouteRecordRaw, createWebHashHistory, Router } from 'vue-router';
import { useStore } from 'vuex';
import appSetting from '@/app-setting';
import HomeView from '../views/index.vue';

const constantRouterMap: RouteRecordRaw[] = [
    { path: '/login', component: () => import('@/views/auth/boxed-signin.vue'), meta: { layout: 'auth' } },
];
const router = createRouter({
    history: createWebHashHistory(),
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRouterMap
})
const asyncRouterMap: RouteRecordRaw[] = [
    {
        path: '/',
        redirect: '/dashboard',
        name: 'dashboard',
        children: [
            { path: 'dashboard', component: () => import('@/views/index.vue'), name: 'dashboard', meta: { title: 'home', icon: 'dashboard', layout: 'app' } }
        ]
    },
    {
        path: '/stock',
        redirect: '/stock',
        name: 'stock',
        children: [
            { path: 'warehouseList', component: () => import('@/views/stock/warehouseList.vue'), name: 'warehouseList', meta: { title: 'warehouseList', layout: 'app' } },
            { path: 'goodsLend', component: () => import('@/views/stock/goodsLend.vue'), name: 'goodsLend', meta: { title: 'goodsLend', layout: 'app' } },
            { path: 'goodsTransfer', component: () => import('@/views/stock/goodsTransfer.vue'), name: 'goodsTransfer', meta: { title: 'goodsTransfer', layout: 'app' } },
            { path: 'goodsExchange', component: () => import('@/views/stock/warehousing.vue'), name: 'goodsExchange', meta: { title: 'goodsExchange' } },
            { path: 'goodsOutBound', component: () => import('@/views/stock/outbound.vue'), name: 'goodsOutBound', meta: { title: 'goodsOutBound' } },
        ]
    }, // 系统管理
    {
        path: '/setting',
        redirect: '/setting',
        name: 'setting',
        meta: {
            title: 'setting',
            icon: 'setting-manage'
        },
        children: [
            { path: 'package', component: () => import('@/views/setting/package.vue'), name: 'package', meta: { title: 'package',layout: 'app' } },
            { path: 'company', component: () => import('@/views/setting/company.vue'), name: 'company', meta: { title: 'company',layout: 'app' } },
            { path: 'roleManage', component: () => import('@/views/setting/roleManage.vue'), name: 'roleManage', meta: { title: 'roleManage',layout: 'app' } },
            /* {
                path: '/setting/system-params',
                component: () => import('@/views/setting/shop-settings/index'),
                redirect: '/setting/system-params/system',
                name: 'systemParams',
                meta: { title: 'systemParams' },
                children: [
                    { path: 'system', component: () => import('@/views/setting/shop-settings/systemSettings'), name: 'systemSettings', meta: { title: 'systemSettings' } },
                    { path: 'storage-solution', component: () => import('@/views/setting/shop-settings/storageSolution'), name: 'storageSolution', meta: { title: 'storageSolution' } },
                    { path: 'dict-data', component: () => import('@/views/setting/tool-manage/dictData'), name: 'dictData', meta: { title: 'dictData' } },
                    { path: 'system-logs', component: () => import('@/views/setting/systemLogs'), name: 'systemLogs', meta: { title: 'systemLogs' } },
                    // serialList

                ]
            },
            {
                path: '/setting/oauth2',
                component: () => import('@/views/setting/shop-settings/index'),
                redirect: '/setting/oauth2/client',
                name: 'oauth2',
                hidden: true,
                meta: { title: 'oauth2' },
                children: [
                    { path: 'client', component: () => import('@/views/setting/oauth2/client'), name: 'oauth2Client', meta: { title: 'oauth2Client' } },
                    { path: 'token', component: () => import('@/views/setting/oauth2/token'), name: 'oauth2Token', meta: { title: 'oauth2Token' } }
                ]
            }, */
           /*  { path: 'administrator-manage', component: () => import('@/views/setting/auth-settings/administratorManage'), name: 'administratorManage', meta: { title: 'administratorManage' } },
            { path: 'role-manage', component: () => import('@/views/setting/auth-settings/roleManage'), name: 'roleManage', meta: { title: 'roleManage' } },
            { path: 'role-permission/:id(\\d+)', component: () => import('@/views/setting/auth-settings/rolePermission'), name: 'roleManageEdit', hidden: true, meta: { title: 'rolePermission', noCache: true } },
            { path: 'role-permission', component: () => import('@/views/setting/auth-settings/rolePermission'), name: 'roleManageAdd', hidden: true, meta: { title: 'rolePermission', noCache: true } },
            { path: 'menu-manage', component: () => import('@/views/setting/tool-manage/menuManage'), name: 'menuManage', meta: { title: 'menuManage' } },
            { path: 'branch', component: () => import('@/views/setting/tool-manage/branch'), name: 'branch', meta: { title: 'branch' } },
            { path: 'station', component: () => import('@/views/setting/tool-manage/station'), name: 'station', meta: { title: 'station' } }, */
        ]
    },
]
asyncRouterMap.forEach(route => {
    router.addRoute(route);
});
/* router.beforeEach((to, from, next) => {package
    const store = useStore();
    //判断当前页面是否带有侧边栏及顶部
    if (to?.meta?.layout == 'auth') {
        store.dispatch("setMainLayout",'auth');
    } else {
        store.dispatch("setMainLayout",'app');
    }
    next(true);
}); */

export { constantRouterMap, asyncRouterMap };
export default router;
